@@ -1,25 +1,25 @@
 module System.Taffybar.Widget.Generic.ChannelGraph where
 
-import BroadcastChan
 import Control.Concurrent
+import Control.Concurrent.STM.TChan
 import Control.Monad
 import Control.Monad.IO.Class
-import Data.Foldable (traverse_)
+import Control.Monad.STM (atomically)
 import GI.Gtk
 import System.Taffybar.Widget.Generic.Graph
 
--- | Given a 'BroadcastChan' and an action to consume that broadcast chan and
+-- | Given a broadcast 'TChan' and an action to consume that broadcast chan and
 -- turn it into graphable values, build a graph that will update as values are
 -- broadcast over the channel.
 channelGraphNew
   :: MonadIO m
-  => GraphConfig -> BroadcastChan In a -> (a -> IO [Double]) -> m GI.Gtk.Widget
+  => GraphConfig -> TChan a -> (a -> IO [Double]) -> m GI.Gtk.Widget
 channelGraphNew config chan sampleBuilder = do
   (graphWidget, graphHandle) <- graphNew config
   _ <- onWidgetRealize graphWidget $ do
-       ourChan <- newBChanListener chan
+       ourChan <- atomically $ dupTChan chan
        sampleThread <- forkIO $ forever $
-         readBChan ourChan >>=
-         traverse_ (graphAddSample graphHandle <=< sampleBuilder)
+         atomically (readTChan ourChan) >>=
+         (graphAddSample graphHandle <=< sampleBuilder)
        void $ onWidgetUnrealize graphWidget $ killThread sampleThread
   return graphWidget
