@@ -1,5 +1,5 @@
 {-# OPTIONS_GHC -fno-warn-type-defaults #-}
-{-# LANGUAGE ScopedTypeVariables, ExistentialQuantification, RankNTypes, OverloadedStrings #-}
+{-# LANGUAGE ScopedTypeVariables, ExistentialQuantification, RankNTypes, OverloadedStrings, StrictData #-}
 -----------------------------------------------------------------------------
 -- |
 -- Module      : System.Taffybar.Widget.Workspaces
@@ -13,7 +13,6 @@
 
 module System.Taffybar.Widget.Workspaces where
 
-import           Control.Applicative
 import           Control.Arrow ((&&&))
 import           Control.Concurrent
 import qualified Control.Concurrent.MVar as MV
@@ -32,7 +31,6 @@ import           Data.List (elemIndex, intersect, sortBy, (\\))
 import qualified Data.Map as M
 import           Data.Maybe
 import qualified Data.MultiMap as MM
-import           Data.Ord
 import qualified Data.Set as Set
 import qualified Data.Text as T
 import           Data.Time.Units
@@ -42,7 +40,6 @@ import qualified GI.Gdk.Enums as Gdk
 import qualified GI.Gdk.Structs.EventScroll as Gdk
 import qualified GI.GdkPixbuf.Objects.Pixbuf as Gdk
 import qualified GI.Gtk as Gtk
-import           Prelude
 import           StatusNotifier.Tray (scalePixbufToSize)
 import           System.Log.Logger
 import           System.Taffybar.Context
@@ -283,7 +280,7 @@ addWidget controller = do
     hbox <- Gtk.boxNew Gtk.OrientationHorizontal 0
     void $ Gtk.widgetGetParent workspaceWidget >>=
          traverse (unsafeCastTo Gtk.Box) >>=
-         traverse (flip Gtk.containerRemove workspaceWidget)
+         traverse (`Gtk.containerRemove` workspaceWidget)
     Gtk.containerAdd hbox workspaceWidget
     Gtk.containerAdd cont hbox
 
@@ -309,7 +306,7 @@ workspacesNew cfg = ask >>= \tContext -> lift $ do
       handleConfigureEvents _ = return ()
   (workspaceSubscription, iconSubscription, geometrySubscription) <-
     flip runReaderT tContext $ sequenceT
-         ( subscribeToPropertyEvents (updateEvents cfg) $ doUpdate
+         ( subscribeToPropertyEvents (updateEvents cfg) doUpdate
          , subscribeToPropertyEvents [ewmhWMIcon] (lift . onIconChanged iconHandler)
          , subscribeToAll handleConfigureEvents
          )
@@ -401,7 +398,7 @@ updateWorkspaceControllers = do
         builder = widgetBuilder cfg
 
     _ <- updateVar controllersRef $ \controllers -> do
-      let oldRemoved = F.foldl (flip M.delete) controllers removeWorkspaces
+      let oldRemoved = F.foldl' (flip M.delete) controllers removeWorkspaces
           buildController idx = builder <$> M.lookup idx workspacesMap
           buildAndAddController theMap idx =
             maybe (return theMap) (>>= return . flip (M.insert idx) theMap)
@@ -429,7 +426,7 @@ onWorkspaceUpdate context = do
         case event of
           PropertyEvent _ _ _ _ _ atom _ _ ->
             wLog DEBUG $ printf "Event %s" $ show atom
-          _ -> return ()
+          _anythingElse -> return ()
         void $ forkIO $ rateLimited event
   return withLog
   where
@@ -683,8 +680,8 @@ constantScaleWindowIconPixbufGetter constantSize getter =
   const $ scaledWindowIconPixbufGetter getter constantSize
 
 handleIconGetterException :: WindowIconPixbufGetter -> WindowIconPixbufGetter
-handleIconGetterException getter =
-  \size windowData -> catchAny (getter size windowData) $ \e -> do
+handleIconGetterException getter size windowData =
+  catchAny (getter size windowData) $ \e -> do
     wLog WARNING $ printf "Failed to get window icon for %s: %s" (show windowData) (show e)
     return Nothing
 
@@ -744,7 +741,7 @@ sortWindowsByPosition wins = do
   let getGeometryWorkspaces w = getDisplay >>= liftIO . (`safeGetGeometry` w)
       getGeometries = mapM
                       (forkM return
-                               ((((sel2 &&& sel3) <$>) .) getGeometryWorkspaces) .
+                               (((sel2 &&& sel3) <$>) . getGeometryWorkspaces) .
                                windowId)
                       wins
   windowGeometries <- liftX11Def [] getGeometries
